#!/bin/bash

echo 
echo "MACH2D 5.8 with TDMA-2D solver"
echo 

echo
echo "INPUT DATA:"
PS3="Choose: "
select opt in Open Skip Quit
do
if [ "$opt" == "Open" ]; then
    echo
    echo Openning input data files...

    emacs ./mach2d-input/parameters.txt

    emacs ./mach2d-input/mach2d-input.dat

    emacs ./mach2d-user.f90

    break
elif [ "$opt" == "Skip" ]; then
    echo
    echo Skipping input data files...
    break
else
    echo
    echo Computation aborted.
    exit 0
fi
done

echo
echo "COMPILATION:"
PS3="Choose: "
select opt in "Parallel Computation" "Serial Computation" "Debug Compilation" Skip Quit
do
if [ "$opt" == "Parallel Computation" ]; then
    echo
    echo Compiling using OpenMP for parallel computation.

    gfortran -O3 -fopenmp\
         tdma2d5.f90\
         tdma2d9.f90\
         mach2d-data.f90\
         mach2d-grid.f90\
         mach2d-coef.f90\
         mach2d-solvers.f90\
         mach2d-user.f90\
         mach2d-postp.f90\
         mach2d-main.f90 -o mach2d.x

    break
elif [ "$opt" == "Serial Computation" ]; then
    echo
    echo Compiling for serial computation.

    gfortran -O3\
         tdma2d5.f90\
         tdma2d9.f90\
         mach2d-data.f90\
         mach2d-grid.f90\
         mach2d-coef.f90\
         mach2d-solvers.f90\
         mach2d-user.f90\
         mach2d-postp.f90\
         mach2d-main.f90 -o mach2d.x

    break
elif [ "$opt" == "Debug Compilation" ]; then
    echo
    echo Debug compilation.

    gfortran -Wall -g\
         tdma2d5.f90\
         tdma2d9.f90\
         mach2d-data.f90\
         mach2d-grid.f90\
         mach2d-coef.f90\
         mach2d-solvers.f90\
         mach2d-user.f90\
         mach2d-postp.f90\
         mach2d-main.f90 -o mach2d.x

    break
elif [ "$opt" == "Skip" ]; then
    echo
    echo Skipping compilation.
    break

elif [ "$opt" == "Quit" ]; then
    echo
    echo Computation aborted.
    exit 0
else
    echo Choose a valid option.
fi
done

echo
echo Removing undesirable files.
rm -f *.dat *.mod *~ *.bin *.out *.o

echo
echo "RUNNING:"
PS3="Choose: "
select opt in Run Quit
do
if [ "$opt" == "Run" ]; then
    echo
    echo Start running...

    ./mach2d.x
    echo
    echo Removing undesirable files.
    rm -f *.dat *.mod *~ *.bin *.out *.o 
    break
else
    echo
    echo Computation aborted.
    exit 0
fi
done
